@@ -76,6 +76,7 @@ static int records = 0;
 static int totalrecords = 0;
 static int timeout = 0;
 static int calldate_compat = 0;
+static int usegmtime = 0;
 
 AST_MUTEX_DEFINE_STATIC(mysql_lock);
 
@@ -250,6 +251,13 @@ db_reconnect:
 					ast_strftime(timestr, sizeof(timestr), "%Y-%m-%d %T", &tm);
 					ast_cdr_setvar(cdr, "calldate", timestr, 0);
 					cdrname = "calldate";
+				} else if (usegmtime) {
+					struct ast_tm tm;
+					char timestr[128];
+					ast_localtime(&cdr->start, &tm, "GMT");
+					ast_strftime(timestr, sizeof(timestr), DATE_FORMAT, &tm);
+					ast_cdr_setvar(cdr, "calldate", timestr, 0);
+					cdrname = "calldate";
 				} else {
 					cdrname = "start";
 				}
@@ -397,6 +405,7 @@ static int my_load_module(int reload)
 	struct column *entry;
 	char *temp;
 	struct ast_str *compat;
+	struct ast_str *gmtime;
 	MYSQL_ROW row;
 	MYSQL_RES *result;
 	char sqldesc[128];
@@ -433,6 +442,7 @@ static int my_load_module(int reload)
 	res |= my_load_config_string(cfg, "global", "sock", &dbsock, "");
 	res |= my_load_config_string(cfg, "global", "table", &dbtable, "cdr");
 	res |= my_load_config_string(cfg, "global", "password", &password, "");
+	res |= my_load_config_string(cfg, "global", "usegmtime", &gmtime, "no");
 
 	res |= my_load_config_string(cfg, "global", "charset", &dbcharset, "");
 
@@ -449,6 +459,12 @@ static int my_load_module(int reload)
 		calldate_compat = 0;
 	}
 
+	if (ast_true(gmtime->str)) {
+		usegmtime = 1;
+	} else {
+		usegmtime = 0;
+	}
+
 	if (res < 0) {
 		if (reload) {
 			AST_RWLIST_UNLOCK(&columns);
