@@ -254,7 +254,7 @@ static struct ast_channel *ooh323_new(struct ooh323_pvt *i, int state,
 
 	/* Don't hold a h323 pvt lock while we allocate a channel */
 	ast_mutex_unlock(&i->lock);
-	ch = ast_channel_alloc(1, state, i->callerid_num, i->callerid_name, i->accountcode, i->exten, i->context, i->amaflags, "OOH323/%s-%08x", host, i);
+	ch = ast_channel_alloc(1, state, i->callerid_num, i->callerid_name, i->accountcode, i->exten, i->context, i->amaflags, "OOH323/%s-%08x", host, (unsigned int)(unsigned long) i);
 	ast_mutex_lock(&i->lock);
 
 	if (ch) {
@@ -455,7 +455,7 @@ static struct ast_channel *ooh323_request(const char *type, int format,
 	/* This is an outgoing call, since ooh323_request is called */
 	ast_set_flag(p, H323_OUTGOING);
 
-	ast_copy_string(tmp, data, sizeof(data));
+	ast_copy_string(tmp, data, sizeof(tmp));
 
 	dest = strchr(tmp, '/');
 
