@@ -1224,7 +1224,7 @@ OOBOOL ooCapabilityCheckCompatibility_Video
                                                               videoCap, dir);
    default:
      OOTRACEDBGC3("ooCapabilityCheckCompatibility_Video - Unsupported video "
-                  "capability. (%s, $s)\n", call->callType, call->callToken);
+                  "capability. (%s, %s)\n", call->callType, call->callToken);
    }
    return FALSE;
 }
@@ -1251,7 +1251,7 @@ OOBOOL ooCapabilityCheckCompatibility
    case T_H245DataType_data:
    default:
       OOTRACEDBGC3("ooCapabilityCheckCompatibility - Unsupported  "
-                  "capability. (%s, $s)\n", call->callType, call->callToken);
+                  "capability. (%s, %s)\n", call->callType, call->callToken);
    }
 
    return FALSE;
