@@ -29,6 +29,10 @@
 #include "ooq931.h"
 #include "MULTIMEDIA-SYSTEM-CONTROL.h"
 
+int ooOnReceivedRoundTripDelayRequest(OOH323CallData *call,
+                                     H245SequenceNumber sequenceNumber);
+
+
 #ifdef __cplusplus
 extern "C" {
 #endif
